﻿$ConfigData = @{
    AllNodes = @(
        @{
            NodeName = "target"
            PSDscAllowPlainTextPassword = $true
        }
    )
}

Configuration InstallWebSite
{
    param([pscredential]$Credential)

    Import-DscResource -ModuleName xReleaseManagement
    
    Node $AllNodes.NodeName
    {
        WindowsFeature InstallIIS
        {
            Ensure = "Present"
            Name = "Web-Server"
        }

        File CreateWebsiteFolder
        {
            Ensure = "Present"
            DependsOn = "[WindowsFeature]InstallIIS"
            DestinationPath = "c:\websites"
            Type = "Directory"
        }

        File CreateLearnDSCFolder
        {
            Ensure = "Present"
            DependsOn = "[File]CreateWebsiteFolder"
            DestinationPath = "c:\websites\learndsc"
            Type = "Directory"
        }

        File CopyBits
        {
           Ensure = "Present"
           SourcePath = "c:\source\"
           DependsOn = "[File]CreateLearnDSCFolder"
           Type = "Directory"
           Recurse = $true
           DestinationPath = "c:\websites\learndsc\"
           Force = $true
           Credential = $Credential
        }

        Trackyon_xTokenize WebConfigs
        {
            Name = "WebConfigs"
            DependsOn = "[File]CopyBits"
            Directory = "c:\websites\learndsc\"
            SearchPattern = "*.config"
            Recurse = $true
            Tokens = @{"database"="demoDBDEv"}            
        }
    }
}

InstallWebsite -ConfigurationData $ConfigData -Credential (Get-Credential)